BlastDirectionality enum
This Dart code snippet defines an enumeration called BlastDirectionality with two possible values:
directional and explosive. Enumerations in Dart are used to define a fixed set of constants. In
this case, BlastDirectionality is used to represent different types of blast directions, such as
directional blasts or explosive blasts.
Values
- directional → const BlastDirectionality
-
Represents a directional blast.
- explosive → const BlastDirectionality
-
Represents an explosive blast.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
BlastDirectionality> - A constant List of the values in this enum, in order of their declaration.