BoxPlotData class

Constructors

BoxPlotData({required String label, required double min, required double q1, required double median, required double q3, required double max, List<double> outliers = const [], required Color color})
const

Properties

color Color
final
hashCode int
The hash code for this object.
no setterinherited
label String
final
max double
final
median double
final
min double
final
outliers List<double>
final
q1 double
final
q3 double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited