ChartLabel class

ChartLabel Model collects and process the JSON based information To update the dynamic chart Labels

Constructors

ChartLabel(String? _type, Color? _color, {bool dynamicColors = false})
Default Constructor for ChartLabel

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited