stop method
void
stop()
The stop function sets the state of a ConfettiController to stopped and notifies listeners.
Implementation
void stop() {
_state = ConfettiControllerState.stopped;
notifyListeners();
}
The stop function sets the state of a ConfettiController to stopped and notifies listeners.
void stop() {
_state = ConfettiControllerState.stopped;
notifyListeners();
}