ConfettiControllerState enum
The enum ConfettiControllerState is defining an enumeration in Dart called
ConfettiControllerState with two possible values: playing and stopped. This enumeration is
used to represent different states that a confetti controller can be in, such as when it is actively
playing confetti or when it has been stopped. Enumerations in Dart are useful for defining a fixed
set of constants that can be used to represent different states or options in your code.
Values
- playing → const ConfettiControllerState
-
Represents that the confetti controller is actively playing confetti.
- stopped → const ConfettiControllerState
-
Represents that the confetti controller has been stopped.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ConfettiControllerState> - A constant List of the values in this enum, in order of their declaration.