emissionFrequency property
The emissionFrequency should be a value between 0 and 1. The higher the value the higher the likelihood that particles will be emitted on a single frame.
Default is set to 0.02 (2% chance).
Implementation
final double emissionFrequency;