CustomGaugeChart class

Inheritance

Constructors

CustomGaugeChart({Key? key, required double value, double minValue = 0, double maxValue = 100, List<GaugeRange> ranges = const [], String? title, String? unit, Color backgroundColor = Colors.white, Color needleColor = Colors.red, TextStyle? textStyle, bool showValue = true, bool showRangeLabels = true, double strokeWidth = 20, double startAngle = 225, double sweepAngle = 270})
const

Properties

backgroundColor Color
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxValue double
final
minValue double
final
needleColor Color
final
ranges List<GaugeRange>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showRangeLabels bool
final
showValue bool
final
startAngle double
final
strokeWidth double
final
sweepAngle double
final
textStyle TextStyle?
final
title String?
final
unit String?
final
value double
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited