DashArray class abstract

The dash array of the line.

Constructors

DashArray()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

dashed([double strokeWidth = 2.0]) List<double>
The dashed line.
dotted([double strokeWidth = 2.0]) List<double>
The dotted line.