LineChartData class

The data is required for LineChart.

Constructors

LineChartData({required List<LineChartDataBar> lineBarsData, MacLineChartXAxis? xAxis, MacLineChartYAxis? yAxis, LineChartArea? area})
Creates LineChartData. When xAxis or yAxis is null, the range is calculated automatically and the label is not shown. When area is null, the area is not shown.

Properties

area LineChartArea?
The plot area drawn on the line chart.
final
hashCode int
The hash code for this object.
no setterinherited
lineBarsData List<LineChartDataBar>
The data determines the appearance of the lines.
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
xAxis → MacLineChartXAxisInternal
The x-axis drawn on the line chart.
final
yAxis → MacLineChartYAxisInternal
The y-axis drawn on the line chart.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited