LineChartLabelText class

The label text of the line chart.

Constructors

LineChartLabelText(double position, String text)
Creates LineChartLabelText.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
position double
The position of the label.
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
text String
The text of the label.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited