LineChartPoint class

The data point for determining the appearance of data points.

Constructors

LineChartPoint({required LineChartPointType type, Color? fillColor, double size = 4, double strokeWidth = 2})
Creates LineChartPoint.
const

Properties

fillColor Color?
The fill color of the point. If null, the color of the area color will be used.
final
hashCode int
The hash code for this object.
no setterinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
The size of the point.
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
strokeWidth double
The stroke width of the point.
final
type LineChartPointType
The type of the point.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited