LineChartXLabel class

The x-label of the line chart.

Inheritance

Constructors

LineChartXLabel({List<LineChartLabelText>? texts, double rotation = 0, TextStyle? style, double spaceFromAxis = 4, LineChartXLabelAlignment alignment = LineChartXLabelAlignment.spaceBetween, int? count, bool hideOverflowedLabels = true, double? height})
Creates LineChartXLabel.
const

Properties

alignment LineChartXLabelAlignment
The alignment of the x-axis labels.
final
count int?
The number of labels to show. If this is null, all labels will be shown.
final
hashCode int
The hash code for this object.
no setterinherited
height double?
The height of the label. If this is null, the height will be calculated automatically.
final
hideOverflowedLabels bool
Whether to hide the labels that overflow the chart. If this is true, the labels that overflow the chart will be hidden.
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
rotation double
The rotation angle of the label. The unit is degree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spaceFromAxis double
The space from the axis.
finalinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
style TextStyle?
The style of the label.
finalinherited
texts List<LineChartLabelText>?
The list of the label text.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pickTexts(LineChartRangeInternal range) List<LineChartLabelText>
Picks the label texts to show.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited