LineChartYLabel class

The y-label of the line chart.

Inheritance

Constructors

LineChartYLabel({List<LineChartLabelText>? texts, double rotation = 0, TextStyle? style, double spaceFromAxis = 4, double? interval, double? width})
Creates LineChartYLabel.
const
LineChartYLabel.create({required List<LineChartDataBar> lineBarsData, required LineChartYLabel label, LineChartRange? range})
Creates LineChartYLabel from the given lineBarsData.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
interval double?
The interval of the labels. If this is null, the interval will be calculated automatically.
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
rotation double
The rotation angle of the label. The unit is degree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spaceFromAxis double
The space from the axis.
finalinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
style TextStyle?
The style of the label.
finalinherited
texts List<LineChartLabelText>?
The list of the label text.
finalinherited
width double?
The width of the label. If this is null, the width will be calculated automatically.
final

Methods

copyWith({List<LineChartLabelText>? texts, double? rotation, TextStyle? style, double? spaceFromAxis, double? interval, double? width}) LineChartYLabel
Creates a copy of this LineChartYLabel but with the given fields
createTexts(LineChartYRangeInternal range) List<LineChartLabelText>
Creates the label texts.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pickTexts(LineChartRangeInternal range) List<LineChartLabelText>
Picks the label texts to show.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

calculateVerticalInterval(double diff) double
Calculates the vertical interval.