LineSeries class

Constructors

LineSeries({required List<LinePoint> points, Color color = Colors.blue, double strokeWidth = 2.0, String? name, bool showPoints = true})
const

Properties

color Color
final
hashCode int
The hash code for this object.
no setterinherited
name String?
final
points List<LinePoint>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showPoints bool
final
strokeWidth double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited