MacLineChartSpot class

The spot of the line chart.

Constructors

MacLineChartSpot(double x, double y)
Creates MacLineChartSpot.
const
MacLineChartSpot.lerp(MacLineChartSpot a, MacLineChartSpot b, double t)
The lerp for use in animation.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
x double
The x value of the spot.
final
y double
The y value of the spot.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited