MacLineChartXAxis class

The x-axis for the line chart.

Constructors

MacLineChartXAxis({LineChartXLabel? label, LineChartGrid? grid, LineChartRange? range})
Creates LineChartAxis.
const

Properties

grid LineChartGrid?
The grid drawn where the label exists. When null, the grid is not shown.
final
hashCode int
The hash code for this object.
no setterinherited
label LineChartXLabel?
The label of the x-axis. When null, the label is not shown.
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
range LineChartRange?
The range of the x-axis. When null, the range is calculated automatically.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited