MacStackChart class

Creates Stack Chart chartData, chartLabel, chartTitle & chartText must be provided and must not be null

Inheritance

Constructors

MacStackChart({Key? key, required String chartTitle, TextStyle? style, required List<ChartData> chartData, required List<ChartLabel> chartLabel, required ChartText chartText, double? containerHeight, double? containerWidth, Color? backgroundColor, Color? chartBackgroundColor, String? dateFormat})
Default Constructor for MacStackChart that process all the given information to the well designed Stack chart
const

Properties

backgroundColor Color?
backgroundColor used for changing the chart's overall widget's background color
final
chartBackgroundColor Color?
chartBackgroundColor used for changing the chart's section background color
final
chartData List<ChartData>
chartData used for loading information to your chart design
final
chartLabel List<ChartLabel>
chartLabel used for label representation for the data provided
final
chartText ChartText
chartText used for horizontal split up difference between each hour. say 10 minutes * 6 = 6 slots per hour
final
chartTitle String
chartTitle used for chart title
final
containerHeight double?
containerHeight used for sample color container's height
final
containerWidth double?
containerWidth used for sample color container's width
final
dateFormat String?
dateFormat used for changing the Date Format (credits: intl dart package), defaults to 'h a'
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style TextStyle?
style used for chart text style includes fontSize, fontColor, fontWeight & much more
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<MacStackChart>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited