stack_chart library
Classes
- AreaChartPainter
- AreaSeries
- Awesome
- Checks if you are awesome. Spoiler: you are.
- BarData
- BoxPlotData
- BoxPlotPainter
- BubbleChartPainter
- BubbleData
- CandleStickData
- CandleStickPainter
- ChartData
- ChartData Model collects and process the JSON based information To update the chart design
- ChartLabel
- ChartLabel Model collects and process the JSON based information To update the dynamic chart Labels
- ChartText
- ChartText Model collects and process the JSON based information To update the dynamic chart time difference between each stack and color for the stack to be filled
- ConfettiController
- ConfettiController is a ChangeNotifier that can be used to control
- ConfettiWidget
- ConfettiWidget is used to create Confetti.
- CustomAreaChart
- CustomBarChart
- CustomBoxPlotChart
- CustomBubbleChart
- CustomCandleStickChart
- CustomDonutChart
- CustomFunnelChart
- CustomGanttChart
- CustomGaugeChart
- CustomHeatMapChart
- CustomHistogram
- CustomLineChart
- CustomPictographChart
- CustomPieChart
- CustomRadarChart
- CustomScatterPlotChart
- CustomStackedBarChart
- CustomTreeMapChart
- CustomTrellisChart
- CustomVennChart
- CustomWaterfallChart
- DashArray
- The dash array of the line.
- DonutChartPainter
- DonutData
- FunnelChartPainter
- FunnelData
- GanttBreak
- GanttChartPainter
- GanttTask
- GaugeChartPainter
- GaugeRange
- HeatMapData
- HeatMapPainter
- HistogramBin
- HistogramPainter
- LineChart
- LineChart renders a line chart.
- LineChartArea
- Line chart area.
- LineChartData
- The data is required for LineChart.
- LineChartDataBar
- The bar data determines the appearances of the line.
- LineChartGrid
- The painter determines the appearance of the grid lines.
- LineChartLabel
- The label of the line chart.
- LineChartLabelText
- The label text of the line chart.
- LineChartPainter
- LineChartPoint
- The data point for determining the appearance of data points.
- LineChartRange
- The range of the line chart.
- LineChartSelectedSpotsPainter
- LineChartSelectedSpotsPainter paints the selected spots on the line chart.
- LineChartTooltip
- The tooltip of the line chart.
- LineChartTooltipDelegate
- The delegate of the tooltip.
- LineChartXLabel
- The x-label of the line chart.
- LineChartYLabel
- The y-label of the line chart.
- LinePoint
- LineSeries
- MacLineChartSpot
- The spot of the line chart.
- MacLineChartXAxis
- The x-axis for the line chart.
- MacLineChartYAxis
- The y-axis for the line chart.
- MacStackChart
- Creates Stack Chart chartData, chartLabel, chartTitle & chartText must be provided and must not be null
- MaLineChartTooltipStyle
- The style of the tooltip.
- NormalizedLineChartData
- The normalized data of LineChartData for smooth animation.
- NormalizedLineChartDataTween
- The tween for use in animation.
- ParticlePainter
-
CustomPainter for the
ParticleSystem. - PictographData
- PieChartPainter
- PieData
- RadarChartPainter
- RadarData
- ScatterPlotPainter
- ScatterPoint
- StackedBarData
- StackedBarSegment
- TreeMapData
- TreeMapPainter
- TrellisData
- TrellisPanelPainter
- TrellisPoint
- VennData
- VennPainter
- WaterfallData
- WaterfallPainter
Enums
- BlastDirectionality
-
This Dart code snippet defines an enumeration called
BlastDirectionalitywith two possible values:directionalandexplosive. Enumerations in Dart are used to define a fixed set of constants. In this case,BlastDirectionalityis used to represent different types of blast directions, such as directional blasts or explosive blasts. - ConfettiControllerState
-
The
enum ConfettiControllerStateis defining an enumeration in Dart calledConfettiControllerStatewith two possible values:playingandstopped. This enumeration is used to represent different states that a confetti controller can be in, such as when it is actively playing confetti or when it has been stopped. Enumerations in Dart are useful for defining a fixed set of constants that can be used to represent different states or options in your code. - LineChartPointType
- The data point type.
- LineChartXLabelAlignment
- The alignment of the x-axis labels.
- MacLineChartTooltipDismissCondition
- The condition to dismiss the tooltip.
- WaterfallType