LineChartGrid class
The painter determines the appearance of the grid lines.
Constructors
- LineChartGrid({Color color = Colors.grey, double strokeWidth = 1})
-
Creates LineChartGrid.
const
Properties
- color → Color
-
The color of the grid lines.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - strokeWidth → double
-
The stroke width of the grid lines.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited