NormalizedLineChartData class
The normalized data of LineChartData for smooth animation.
Constructors
-
NormalizedLineChartData({required List<
LineChartDataBar> lineBarsData, required MacLineChartXAxisInternal xAxis, required MacLineChartYAxisInternal yAxis, LineChartArea? area}) -
Creates NormalizedLineChartData.
const
- NormalizedLineChartData.lerp(NormalizedLineChartData a, NormalizedLineChartData b, double t)
-
The lerp for use in animation.
factory
- NormalizedLineChartData.normalized(LineChartData data)
-
Normalizes the data.
factory
Properties
- area → LineChartArea?
-
The plot area drawn on the line chart.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
lineBarsData
→ List<
LineChartDataBar> -
The data determines the appearance of the lines.
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - xAxis → MacLineChartXAxisInternal
-
The x-axis drawn on the line chart.
final
- yAxis → MacLineChartYAxisInternal
-
The y-axis drawn on the line chart.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited